read_fasta

Function read_fasta 

pub fn read_fasta(
    fasta_path: &str,
) -> Result<FastxRecords<IndexedSequence>, String>
Reads a FASTA file and returns a collection of records.

Arguments

  • fasta_path - Path to a FASTA file

Errors

Returns an error if the file cannot be opened, any line cannot be read, or the file contains no valid header+sequence pairs.