FastxRecords

Struct FastxRecords 

pub struct FastxRecords<T> { /* private fields */ }
Generic collection of sequence records, indexed by name.

Implementations

Source

impl<T: FastxRecord> FastxRecords<T>

pub fn num_records(&self) -> usize

Return record count.

pub fn get_max_length(&self) -> usize

Return length of the longest sequence

pub fn records_by_name(&self, names: Vec<String>) -> (FastxRecords<T>, String)

Return a subset of records from a list of names.

Arguments
  • names - A list of record names, not necessarily all present in the current object.
Returns

A tuple containing a FastxRecords object with any records present in the input list and a list of names not found. An empty list returns an empty object. Record indexes still refer to the original file. Duplicate record names are removed in the FastxRecords object but not in the list of absent records.

pub fn subsequences(&self, start: usize, end: usize) -> FastxRecords<T>

Return subsequences of all records.

Arguments
  • start - Base-0 start position (inclusive)
  • end - Base-0 end position (exclusive)
Returns

A FastxRecords object with all records, but with the subsequence between start and end.

pub fn subsequences_by_name( &self, names_ranges: Vec<NameWithRange>, ) -> (FastxRecords<T>, String)

Return subsequences of named records.

Arguments
  • names_ranges - Record names and ranges.
Returns

A tuple containing a FastxRecords object with subsets of any records present in the input list and a list of names not found. An empty list returns an empty object. Record indexes still refer to the original file. Duplicate record names are removed in the FastxRecords object but not in the list of absent records.

pub fn merge(&mut self, from: FastxRecords<T>)

Merge in a FastxRecords object.

Any records also present in the current object are overwritten by new values.

Arguments
  • from - an object to merge
pub fn save_records(&self, output_path: &str) -> Result<(), String>

Save the records to a file.

Arguments
  • output_path - Path to a file
Errors

Returns an error if the file cannot be created or any record cannot be written.

pub fn save_sorted_records(&self, output_path: &str) -> Result<(), String>

Save the records in the order they appeared in the original file.

Arguments
  • output_path - Path to a file
Errors

Returns an error if the file cannot be created or any record cannot be written.